@@ -1,4 +1,3 @@
-import types
 import typing
 
 import pkg_resources
@@ -7,11 +6,11 @@ from .order import Order
 
 
 def choice_in_order(
-        module_names: typing.List[str],
-        order: Order = Order.TO_RIGHT,
-        do_import: bool = False,
-        default: typing.Optional[str] = None
-) -> typing.Union[str, types.ModuleType]:
+    module_names: typing.List[str],
+    order: Order = Order.TO_RIGHT,
+    do_import: bool = False,
+    default: typing.Optional[str] = None,
+) -> typing.Union[str, typing.Any]:
     """ Finds out installed module from list based on order
     :param module_names: list of module names
     :param order: order from worst to best to be installed
@@ -19,9 +18,16 @@ def choice_in_order(
     :param default: default module name
     :return: module if do_import else module_name
     """
-    installed = [pkg.key for pkg in pkg_resources.working_set if pkg.key in module_names]
+    default = default or module_names[0]
+    installed = [
+        pkg.key for pkg in pkg_resources.working_set if pkg.key in module_names
+    ]
     if not installed and default is None:
-        raise ModuleNotFoundError("No required module variation was found. List: {}".format(", ".join(module_names)))
+        raise ModuleNotFoundError(
+            "No required module variation was found. List: {}".format(
+                ", ".join(module_names)
+            )
+        )
 
     ordered_module_name = installed[order.value] if installed else default
     return ordered_module_name if not do_import else __import__(ordered_module_name)
